@@ -8,7 +8,13 @@ logger = logging.getLogger(__name__)
 
 
 def run_borg(
-    repository, storage, local_borg_version, borg_arguments, local_path, remote_path,
+    repository,
+    config,
+    local_borg_version,
+    borg_arguments,
+    global_arguments,
+    local_path,
+    remote_path,
 ):
     '''
     Run the "borg" action for the given repository.
@@ -16,18 +22,21 @@ def run_borg(
     if borg_arguments.repository is None or borgmatic.config.validate.repositories_match(
         repository, borg_arguments.repository
     ):
-        logger.info('{}: Running arbitrary Borg command'.format(repository))
+        logger.info(
+            f'{repository.get("label", repository["path"])}: Running arbitrary Borg command'
+        )
         archive_name = borgmatic.borg.rlist.resolve_archive_name(
-            repository,
+            repository['path'],
             borg_arguments.archive,
-            storage,
+            config,
             local_borg_version,
+            global_arguments,
             local_path,
             remote_path,
         )
         borgmatic.borg.borg.run_arbitrary_borg(
-            repository,
-            storage,
+            repository['path'],
+            config,
             local_borg_version,
             options=borg_arguments.options,
             archive=archive_name,
