@@ -5,7 +5,9 @@ import subprocess
 import sys
 import tempfile
 
+import pymongo
 import pytest
+import ruamel.yaml
 
 
 def write_configuration(
@@ -21,7 +23,7 @@ def write_configuration(
     for testing. This includes injecting the given repository path, borgmatic source directory for
     storing database dumps, dump format (for PostgreSQL), and encryption passphrase.
     '''
-    config = f'''
+    config_yaml = f'''
 source_directories:
     - {source_directory}
 repositories:
@@ -45,18 +47,32 @@ postgresql_databases:
       hostname: postgresql
       username: postgres
       password: test
-mysql_databases:
+mariadb_databases:
     - name: test
-      hostname: mysql
+      hostname: mariadb
       username: root
       password: test
     - name: all
-      hostname: mysql
+      hostname: mariadb
       username: root
       password: test
     - name: all
       format: sql
-      hostname: mysql
+      hostname: mariadb
+      username: root
+      password: test
+mysql_databases:
+    - name: test
+      hostname: not-actually-mysql
+      username: root
+      password: test
+    - name: all
+      hostname: not-actually-mysql
+      username: root
+      password: test
+    - name: all
+      format: sql
+      hostname: not-actually-mysql
       username: root
       password: test
 mongodb_databases:
@@ -76,7 +92,9 @@ sqlite_databases:
 '''
 
     with open(config_path, 'w') as config_file:
-        config_file.write(config)
+        config_file.write(config_yaml)
+
+    return ruamel.yaml.YAML(typ='safe').load(config_yaml)
 
 
 def write_custom_restore_configuration(
@@ -92,7 +110,7 @@ def write_custom_restore_configuration(
     for testing with custom restore options. This includes a custom restore_hostname, restore_port,
     restore_username, restore_password and restore_path.
     '''
-    config = f'''
+    config_yaml = f'''
 source_directories:
     - {source_directory}
 repositories:
@@ -109,14 +127,22 @@ postgresql_databases:
       format: {postgresql_dump_format}
       restore_hostname: postgresql2
       restore_port: 5433
-      restore_username: postgres2
+      restore_password: test2
+mariadb_databases:
+    - name: test
+      hostname: mariadb
+      username: root
+      password: test
+      restore_hostname: mariadb2
+      restore_port: 3307
+      restore_username: root
       restore_password: test2
 mysql_databases:
     - name: test
-      hostname: mysql
+      hostname: not-actually-mysql
       username: root
       password: test
-      restore_hostname: mysql2
+      restore_hostname: not-actually-mysql2
       restore_port: 3307
       restore_username: root
       restore_password: test2
@@ -138,7 +164,9 @@ sqlite_databases:
 '''
 
     with open(config_path, 'w') as config_file:
-        config_file.write(config)
+        config_file.write(config_yaml)
+
+    return ruamel.yaml.YAML(typ='safe').load(config_yaml)
 
 
 def write_simple_custom_restore_configuration(
@@ -154,7 +182,7 @@ def write_simple_custom_restore_configuration(
     custom restore_hostname, restore_port, restore_username and restore_password as we only test
     these options for PostgreSQL.
     '''
-    config = f'''
+    config_yaml = f'''
 source_directories:
     - {source_directory}
 repositories:
@@ -172,7 +200,147 @@ postgresql_databases:
 '''
 
     with open(config_path, 'w') as config_file:
-        config_file.write(config)
+        config_file.write(config_yaml)
+
+    return ruamel.yaml.YAML(typ='safe').load(config_yaml)
+
+
+def get_connection_params(database, use_restore_options=False):
+    hostname = (database.get('restore_hostname') if use_restore_options else None) or database.get(
+        'hostname'
+    )
+    port = (database.get('restore_port') if use_restore_options else None) or database.get('port')
+    username = (database.get('restore_username') if use_restore_options else None) or database.get(
+        'username'
+    )
+    password = (database.get('restore_password') if use_restore_options else None) or database.get(
+        'password'
+    )
+
+    return (hostname, port, username, password)
+
+
+def run_postgresql_command(command, config, use_restore_options=False):
+    (hostname, port, username, password) = get_connection_params(
+        config['postgresql_databases'][0], use_restore_options
+    )
+
+    subprocess.check_call(
+        [
+            '/usr/bin/psql',
+            f'--host={hostname}',
+            f'--port={port or 5432}',
+            f"--username={username or 'root'}",
+            f'--command={command}',
+            'test',
+        ],
+        env={'PGPASSWORD': password},
+    )
+
+
+def run_mariadb_command(command, config, use_restore_options=False, binary_name='mariadb'):
+    (hostname, port, username, password) = get_connection_params(
+        config[f'{binary_name}_databases'][0], use_restore_options
+    )
+
+    subprocess.check_call(
+        [
+            f'/usr/bin/{binary_name}',
+            f'--host={hostname}',
+            f'--port={port or 3306}',
+            f'--user={username}',
+            f'--execute={command}',
+            'test',
+        ],
+        env={'MYSQL_PWD': password},
+    )
+
+
+def get_mongodb_database_client(config, use_restore_options=False):
+    (hostname, port, username, password) = get_connection_params(
+        config['mongodb_databases'][0], use_restore_options
+    )
+
+    return pymongo.MongoClient(f'mongodb://{username}:{password}@{hostname}:{port or 27017}').test
+
+
+def run_sqlite_command(command, config, use_restore_options=False):
+    database = config['sqlite_databases'][0]
+    path = (database.get('restore_path') if use_restore_options else None) or database.get('path')
+
+    subprocess.check_call(
+        [
+            '/usr/bin/sqlite3',
+            path,
+            command,
+            '.exit',
+        ],
+    )
+
+
+DEFAULT_HOOK_NAMES = {'postgresql', 'mariadb', 'mysql', 'mongodb', 'sqlite'}
+
+
+def create_test_tables(config, use_restore_options=False):
+    '''
+    Create test tables for borgmatic to dump and backup.
+    '''
+    command = 'create table test{id} (thing int); insert into test{id} values (1);'
+
+    if 'postgresql_databases' in config:
+        run_postgresql_command(command.format(id=1), config, use_restore_options)
+    if 'mariadb_databases' in config:
+        run_mariadb_command(command.format(id=2), config, use_restore_options)
+    if 'mysql_databases' in config:
+        run_mariadb_command(command.format(id=3), config, use_restore_options, binary_name='mysql')
+    if 'mongodb_databases' in config:
+        get_mongodb_database_client(config, use_restore_options)['test4'].insert_one({'thing': 1})
+    if 'sqlite_databases' in config:
+        run_sqlite_command(command.format(id=5), config, use_restore_options)
+
+
+def drop_test_tables(config, use_restore_options=False):
+    '''
+    Drop the test tables in preparation for borgmatic restoring them.
+    '''
+    command = 'drop table if exists test{id};'
+
+    if 'postgresql_databases' in config:
+        run_postgresql_command(command.format(id=1), config, use_restore_options)
+    if 'mariadb_databases' in config:
+        run_mariadb_command(command.format(id=2), config, use_restore_options)
+    if 'mysql_databases' in config:
+        run_mariadb_command(command.format(id=3), config, use_restore_options, binary_name='mysql')
+    if 'mongodb_databases' in config:
+        get_mongodb_database_client(config, use_restore_options)['test4'].drop()
+    if 'sqlite_databases' in config:
+        run_sqlite_command(command.format(id=5), config, use_restore_options)
+
+
+def select_test_tables(config, use_restore_options=False):
+    '''
+    Select the test tables to make sure they exist.
+
+    Raise if the expected tables cannot be selected, for instance if a restore hasn't worked as
+    expected.
+    '''
+    command = 'select count(*) from test{id};'
+
+    if 'postgresql_databases' in config:
+        run_postgresql_command(command.format(id=1), config, use_restore_options)
+    if 'mariadb_databases' in config:
+        run_mariadb_command(command.format(id=2), config, use_restore_options)
+    if 'mysql_databases' in config:
+        run_mariadb_command(command.format(id=3), config, use_restore_options, binary_name='mysql')
+    if 'mongodb_databases' in config:
+        assert (
+            get_mongodb_database_client(config, use_restore_options)['test4'].count_documents(
+                filter={}
+            )
+            > 0
+        )
+    if 'sqlite_databases' in config:
+        run_sqlite_command(command.format(id=5), config, use_restore_options)
 
 
 def test_database_dump_and_restore():
@@ -188,15 +356,17 @@ def test_database_dump_and_restore():
 
     try:
         config_path = os.path.join(temporary_directory, 'test.yaml')
-        write_configuration(
+        config = write_configuration(
             temporary_directory, config_path, repository_path, borgmatic_source_directory
         )
+        create_test_tables(config)
+        select_test_tables(config)
 
         subprocess.check_call(
             ['borgmatic', '-v', '2', '--config', config_path, 'rcreate', '--encryption', 'repokey']
         )
 
-        # Run borgmatic to generate a backup archive including a database dump.
+        # Run borgmatic to generate a backup archive including database dumps.
         subprocess.check_call(['borgmatic', 'create', '--config', config_path, '-v', '2'])
 
         # Get the created archive name.
@@ -209,16 +379,21 @@ def test_database_dump_and_restore():
         assert len(parsed_output[0]['archives']) == 1
         archive_name = parsed_output[0]['archives'][0]['archive']
 
-        # Restore the database from the archive.
+        # Restore the databases from the archive.
+        drop_test_tables(config)
         subprocess.check_call(
             ['borgmatic', '-v', '2', '--config', config_path, 'restore', '--archive', archive_name]
         )
+
+        # Ensure the test tables have actually been restored.
+        select_test_tables(config)
     finally:
         os.chdir(original_working_directory)
         shutil.rmtree(temporary_directory)
+        drop_test_tables(config)
 
 
-def test_database_dump_and_restore_with_restore_cli_arguments():
+def test_database_dump_and_restore_with_restore_cli_flags():
     # Create a Borg repository.
     temporary_directory = tempfile.mkdtemp()
     repository_path = os.path.join(temporary_directory, 'test.borg')
@@ -228,9 +403,11 @@ def test_database_dump_and_restore_with_restore_cli_arguments():
 
     try:
         config_path = os.path.join(temporary_directory, 'test.yaml')
-        write_simple_custom_restore_configuration(
+        config = write_simple_custom_restore_configuration(
             temporary_directory, config_path, repository_path, borgmatic_source_directory
         )
+        create_test_tables(config)
+        select_test_tables(config)
 
         subprocess.check_call(
             ['borgmatic', '-v', '2', '--config', config_path, 'rcreate', '--encryption', 'repokey']
@@ -250,6 +427,7 @@ def test_database_dump_and_restore_with_restore_cli_arguments():
         archive_name = parsed_output[0]['archives'][0]['archive']
 
         # Restore the database from the archive.
+        drop_test_tables(config)
         subprocess.check_call(
             [
                 'borgmatic',
@@ -264,15 +442,25 @@ def test_database_dump_and_restore_with_restore_cli_arguments():
                 'postgresql2',
                 '--port',
                 '5433',
-                '--username',
-                'postgres2',
                 '--password',
                 'test2',
             ]
         )
+
+        # Ensure the test tables have actually been restored. But first modify the config to contain
+        # the altered restore values from the borgmatic command above. This ensures that the test
+        # tables are selected from the correct database.
+        database = config['postgresql_databases'][0]
+        database['restore_hostname'] = 'postgresql2'
+        database['restore_port'] = '5433'
+        database['restore_password'] = 'test2'
+
+        select_test_tables(config, use_restore_options=True)
     finally:
         os.chdir(original_working_directory)
         shutil.rmtree(temporary_directory)
+        drop_test_tables(config)
+        drop_test_tables(config, use_restore_options=True)
 
 
 def test_database_dump_and_restore_with_restore_configuration_options():
@@ -285,9 +473,11 @@ def test_database_dump_and_restore_with_restore_configuration_options():
 
     try:
         config_path = os.path.join(temporary_directory, 'test.yaml')
-        write_custom_restore_configuration(
+        config = write_custom_restore_configuration(
             temporary_directory, config_path, repository_path, borgmatic_source_directory
         )
+        create_test_tables(config)
+        select_test_tables(config)
 
         subprocess.check_call(
             ['borgmatic', '-v', '2', '--config', config_path, 'rcreate', '--encryption', 'repokey']
@@ -307,12 +497,18 @@ def test_database_dump_and_restore_with_restore_configuration_options():
         archive_name = parsed_output[0]['archives'][0]['archive']
 
         # Restore the database from the archive.
+        drop_test_tables(config)
         subprocess.check_call(
             ['borgmatic', '-v', '2', '--config', config_path, 'restore', '--archive', archive_name]
         )
+
+        # Ensure the test tables have actually been restored.
+        select_test_tables(config, use_restore_options=True)
     finally:
         os.chdir(original_working_directory)
         shutil.rmtree(temporary_directory)
+        drop_test_tables(config)
+        drop_test_tables(config, use_restore_options=True)
 
 
 def test_database_dump_and_restore_with_directory_format():
@@ -325,7 +521,7 @@ def test_database_dump_and_restore_with_directory_format():
 
     try:
         config_path = os.path.join(temporary_directory, 'test.yaml')
-        write_configuration(
+        config = write_configuration(
             temporary_directory,
             config_path,
             repository_path,
@@ -333,6 +529,8 @@ def test_database_dump_and_restore_with_directory_format():
             postgresql_dump_format='directory',
             mongodb_dump_format='directory',
         )
+        create_test_tables(config)
+        select_test_tables(config)
 
         subprocess.check_call(
             ['borgmatic', '-v', '2', '--config', config_path, 'rcreate', '--encryption', 'repokey']
@@ -342,12 +540,17 @@ def test_database_dump_and_restore_with_directory_format():
         subprocess.check_call(['borgmatic', 'create', '--config', config_path, '-v', '2'])
 
         # Restore the database from the archive.
+        drop_test_tables(config)
         subprocess.check_call(
             ['borgmatic', '--config', config_path, 'restore', '--archive', 'latest']
         )
+
+        # Ensure the test tables have actually been restored.
+        select_test_tables(config)
     finally:
         os.chdir(original_working_directory)
         shutil.rmtree(temporary_directory)
+        drop_test_tables(config)
 
 
 def test_database_dump_with_error_causes_borgmatic_to_exit():
