@@ -10,7 +10,7 @@ def test_destroy_monitor_removes_healthchecks_handler():
     original_handlers = list(logger.handlers)
     logger.addHandler(module.Forgetful_buffering_handler(byte_capacity=100, log_level=1))
 
-    module.destroy_monitor(flexmock(), flexmock(), flexmock(), flexmock())
+    module.destroy_monitor(flexmock(), flexmock(), flexmock(), flexmock(), flexmock())
 
     assert logger.handlers == original_handlers
 
@@ -19,6 +19,6 @@ def test_destroy_monitor_without_healthchecks_handler_does_not_raise():
     logger = logging.getLogger()
     original_handlers = list(logger.handlers)
 
-    module.destroy_monitor(flexmock(), flexmock(), flexmock(), flexmock())
+    module.destroy_monitor(flexmock(), flexmock(), flexmock(), flexmock(), flexmock())
 
     assert logger.handlers == original_handlers
