@@ -5,24 +5,22 @@ from borgmatic.actions import check as module
 
 def test_run_check_calls_hooks_for_configured_repository():
     flexmock(module.logger).answer = lambda message: None
-    flexmock(module.borgmatic.config.checks).should_receive(
-        'repository_enabled_for_checks'
-    ).and_return(True)
     flexmock(module.borgmatic.config.validate).should_receive('repositories_match').never()
     flexmock(module.borgmatic.borg.check).should_receive('check_archives').once()
     flexmock(module.borgmatic.hooks.command).should_receive('execute_hook').times(2)
     check_arguments = flexmock(
-        repository=None, progress=flexmock(), repair=flexmock(), only=flexmock(), force=flexmock(),
+        repository=None,
+        progress=flexmock(),
+        repair=flexmock(),
+        only=flexmock(),
+        force=flexmock(),
     )
     global_arguments = flexmock(monitoring_verbosity=1, dry_run=False)
 
     module.run_check(
         config_filename='test.yaml',
         repository={'path': 'repo'},
-        location={'repositories': ['repo']},
-        storage={},
-        consistency={},
-        hooks={},
+        config={'repositories': ['repo']},
         hook_context={},
         local_borg_version=None,
         check_arguments=check_arguments,
@@ -50,10 +48,7 @@ def test_run_check_runs_with_selected_repository():
     module.run_check(
         config_filename='test.yaml',
         repository={'path': 'repo'},
-        location={'repositories': ['repo']},
-        storage={},
-        consistency={},
-        hooks={},
+        config={'repositories': ['repo']},
         hook_context={},
         local_borg_version=None,
         check_arguments=check_arguments,
@@ -81,10 +76,7 @@ def test_run_check_bails_if_repository_does_not_match():
     module.run_check(
         config_filename='test.yaml',
         repository={'path': 'repo'},
-        location={'repositories': ['repo']},
-        storage={},
-        consistency={},
-        hooks={},
+        config={'repositories': ['repo']},
         hook_context={},
         local_borg_version=None,
         check_arguments=check_arguments,
