@@ -10,7 +10,9 @@ from ..test_verbosity import insert_logging_mock
 def insert_execute_command_mock(command):
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
-        command, borg_local_path='borg', extra_environment=None,
+        command,
+        borg_local_path='borg',
+        extra_environment=None,
     ).once()
 
 
@@ -19,7 +21,10 @@ def test_break_lock_calls_borg_with_required_flags():
     insert_execute_command_mock(('borg', 'break-lock', 'repo'))
 
     module.break_lock(
-        repository_path='repo', storage_config={}, local_borg_version='1.2.3',
+        repository_path='repo',
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -28,7 +33,11 @@ def test_break_lock_calls_borg_with_remote_path_flags():
     insert_execute_command_mock(('borg', 'break-lock', '--remote-path', 'borg1', 'repo'))
 
     module.break_lock(
-        repository_path='repo', storage_config={}, local_borg_version='1.2.3', remote_path='borg1',
+        repository_path='repo',
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+        remote_path='borg1',
     )
 
 
@@ -37,7 +46,22 @@ def test_break_lock_calls_borg_with_umask_flags():
     insert_execute_command_mock(('borg', 'break-lock', '--umask', '0770', 'repo'))
 
     module.break_lock(
-        repository_path='repo', storage_config={'umask': '0770'}, local_borg_version='1.2.3',
+        repository_path='repo',
+        config={'umask': '0770'},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+    )
+
+
+def test_break_lock_calls_borg_with_log_json_flags():
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+    insert_execute_command_mock(('borg', 'break-lock', '--log-json', 'repo'))
+
+    module.break_lock(
+        repository_path='repo',
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=True),
     )
 
 
@@ -46,7 +70,10 @@ def test_break_lock_calls_borg_with_lock_wait_flags():
     insert_execute_command_mock(('borg', 'break-lock', '--lock-wait', '5', 'repo'))
 
     module.break_lock(
-        repository_path='repo', storage_config={'lock_wait': '5'}, local_borg_version='1.2.3',
+        repository_path='repo',
+        config={'lock_wait': '5'},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -56,7 +83,10 @@ def test_break_lock_with_log_info_calls_borg_with_info_parameter():
     insert_logging_mock(logging.INFO)
 
     module.break_lock(
-        repository_path='repo', storage_config={}, local_borg_version='1.2.3',
+        repository_path='repo',
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -66,5 +96,8 @@ def test_break_lock_with_log_debug_calls_borg_with_debug_flags():
     insert_logging_mock(logging.DEBUG)
 
     module.break_lock(
-        repository_path='repo', storage_config={}, local_borg_version='1.2.3',
+        repository_path='repo',
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
