@@ -11,7 +11,9 @@ from ..test_verbosity import insert_logging_mock
 def insert_execute_command_mock(command, working_directory=None):
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
-        command, working_directory=working_directory, extra_environment=None,
+        command,
+        working_directory=working_directory,
+        extra_environment=None,
     ).once()
 
 
@@ -23,7 +25,11 @@ def test_extract_last_archive_dry_run_calls_borg_with_last_archive():
     )
 
     module.extract_last_archive_dry_run(
-        storage_config={}, local_borg_version='1.2.3', repository_path='repo', lock_wait=None
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+        repository_path='repo',
+        lock_wait=None,
     )
 
 
@@ -32,7 +38,11 @@ def test_extract_last_archive_dry_run_without_any_archives_should_not_raise():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(('repo',))
 
     module.extract_last_archive_dry_run(
-        storage_config={}, local_borg_version='1.2.3', repository_path='repo', lock_wait=None
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+        repository_path='repo',
+        lock_wait=None,
     )
 
 
@@ -45,7 +55,11 @@ def test_extract_last_archive_dry_run_with_log_info_calls_borg_with_info_paramet
     )
 
     module.extract_last_archive_dry_run(
-        storage_config={}, local_borg_version='1.2.3', repository_path='repo', lock_wait=None
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+        repository_path='repo',
+        lock_wait=None,
     )
 
 
@@ -60,7 +74,11 @@ def test_extract_last_archive_dry_run_with_log_debug_calls_borg_with_debug_param
     )
 
     module.extract_last_archive_dry_run(
-        storage_config={}, local_borg_version='1.2.3', repository_path='repo', lock_wait=None
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+        repository_path='repo',
+        lock_wait=None,
     )
 
 
@@ -72,15 +90,16 @@ def test_extract_last_archive_dry_run_calls_borg_via_local_path():
     )
 
     module.extract_last_archive_dry_run(
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
         repository_path='repo',
         lock_wait=None,
         local_path='borg1',
     )
 
 
-def test_extract_last_archive_dry_run_calls_borg_with_remote_path_parameters():
+def test_extract_last_archive_dry_run_calls_borg_with_remote_path_flags():
     flexmock(module.rlist).should_receive('resolve_archive_name').and_return('archive')
     insert_execute_command_mock(
         ('borg', 'extract', '--dry-run', '--remote-path', 'borg1', 'repo::archive')
@@ -90,15 +109,32 @@ def test_extract_last_archive_dry_run_calls_borg_with_remote_path_parameters():
     )
 
     module.extract_last_archive_dry_run(
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
         repository_path='repo',
         lock_wait=None,
         remote_path='borg1',
     )
 
 
-def test_extract_last_archive_dry_run_calls_borg_with_lock_wait_parameters():
+def test_extract_last_archive_dry_run_calls_borg_with_log_json_flag():
+    flexmock(module.rlist).should_receive('resolve_archive_name').and_return('archive')
+    insert_execute_command_mock(('borg', 'extract', '--dry-run', '--log-json', 'repo::archive'))
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',)
+    )
+
+    module.extract_last_archive_dry_run(
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=True),
+        repository_path='repo',
+        lock_wait=None,
+    )
+
+
+def test_extract_last_archive_dry_run_calls_borg_with_lock_wait_flags():
     flexmock(module.rlist).should_receive('resolve_archive_name').and_return('archive')
     insert_execute_command_mock(
         ('borg', 'extract', '--dry-run', '--lock-wait', '5', 'repo::archive')
@@ -108,51 +144,65 @@ def test_extract_last_archive_dry_run_calls_borg_with_lock_wait_parameters():
     )
 
     module.extract_last_archive_dry_run(
-        storage_config={}, local_borg_version='1.2.3', repository_path='repo', lock_wait=5
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+        repository_path='repo',
+        lock_wait=5,
     )
 
 
-def test_extract_archive_calls_borg_with_path_parameters():
+def test_extract_archive_calls_borg_with_path_flags():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     insert_execute_command_mock(('borg', 'extract', 'repo::archive', 'path1', 'path2'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=['path1', 'path2'],
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
-def test_extract_archive_calls_borg_with_remote_path_parameters():
+def test_extract_archive_calls_borg_with_remote_path_flags():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     insert_execute_command_mock(('borg', 'extract', '--remote-path', 'borg1', 'repo::archive'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
         remote_path='borg1',
     )
 
 
 @pytest.mark.parametrize(
-    'feature_available,option_flag', ((True, '--numeric-ids'), (False, '--numeric-owner'),),
+    'feature_available,option_flag',
+    (
+        (True, '--numeric-ids'),
+        (False, '--numeric-owner'),
+    ),
 )
 def test_extract_archive_calls_borg_with_numeric_ids_parameter(feature_available, option_flag):
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
@@ -161,40 +211,46 @@ def test_extract_archive_calls_borg_with_numeric_ids_parameter(feature_available
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={'numeric_ids': True},
-        storage_config={},
+        config={'numeric_ids': True},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
-def test_extract_archive_calls_borg_with_umask_parameters():
+def test_extract_archive_calls_borg_with_umask_flags():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     insert_execute_command_mock(('borg', 'extract', '--umask', '0770', 'repo::archive'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={'umask': '0770'},
+        config={'umask': '0770'},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
-def test_extract_archive_calls_borg_with_lock_wait_parameters():
+def test_extract_archive_calls_borg_with_log_json_flags():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
-    insert_execute_command_mock(('borg', 'extract', '--lock-wait', '5', 'repo::archive'))
+    insert_execute_command_mock(('borg', 'extract', '--log-json', 'repo::archive'))
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
@@ -205,9 +261,31 @@ def test_extract_archive_calls_borg_with_lock_wait_parameters():
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={'lock_wait': '5'},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=True),
+    )
+
+
+def test_extract_archive_calls_borg_with_lock_wait_flags():
+    flexmock(module.os.path).should_receive('abspath').and_return('repo')
+    insert_execute_command_mock(('borg', 'extract', '--lock-wait', '5', 'repo::archive'))
+    flexmock(module.feature).should_receive('available').and_return(True)
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',)
+    )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
+
+    module.extract_archive(
+        dry_run=False,
+        repository='repo',
+        archive='archive',
+        paths=None,
+        config={'lock_wait': '5'},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -219,19 +297,22 @@ def test_extract_archive_with_log_info_calls_borg_with_info_parameter():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
-def test_extract_archive_with_log_debug_calls_borg_with_debug_parameters():
+def test_extract_archive_with_log_debug_calls_borg_with_debug_flags():
     flexmock(module.os.path).should_receive('abspath').and_return('repo')
     insert_execute_command_mock(
         ('borg', 'extract', '--debug', '--list', '--show-rc', 'repo::archive')
@@ -241,15 +322,18 @@ def test_extract_archive_with_log_debug_calls_borg_with_debug_parameters():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -260,15 +344,18 @@ def test_extract_archive_calls_borg_with_dry_run_parameter():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=True,
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -279,15 +366,18 @@ def test_extract_archive_calls_borg_with_destination_path():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
         destination_path='/dest',
     )
 
@@ -299,15 +389,18 @@ def test_extract_archive_calls_borg_with_strip_components():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
         strip_components=5,
     )
 
@@ -329,15 +422,18 @@ def test_extract_archive_calls_borg_with_strip_components_calculated_from_all():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=['foo/bar/baz.txt', 'foo/bar.txt'],
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
         strip_components='all',
     )
 
@@ -348,6 +444,9 @@ def test_extract_archive_with_strip_components_all_and_no_paths_raises():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
     flexmock(module).should_receive('execute_command').never()
 
     with pytest.raises(ValueError):
@@ -356,9 +455,9 @@ def test_extract_archive_with_strip_components_all_and_no_paths_raises():
             repository='repo',
             archive='archive',
             paths=None,
-            location_config={},
-            storage_config={},
+            config={},
             local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
             strip_components='all',
         )
 
@@ -376,15 +475,18 @@ def test_extract_archive_calls_borg_with_progress_parameter():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
         progress=True,
     )
 
@@ -398,9 +500,9 @@ def test_extract_archive_with_progress_and_extract_to_stdout_raises():
             repository='repo',
             archive='archive',
             paths=None,
-            location_config={},
-            storage_config={},
+            config={},
             local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
             progress=True,
             extract_to_stdout=True,
         )
@@ -421,6 +523,9 @@ def test_extract_archive_calls_borg_with_stdout_parameter_and_returns_process():
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     assert (
         module.extract_archive(
@@ -428,9 +533,9 @@ def test_extract_archive_calls_borg_with_stdout_parameter_and_returns_process():
             repository='repo',
             archive='archive',
             paths=None,
-            location_config={},
-            storage_config={},
+            config={},
             local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
             extract_to_stdout=True,
         )
         == process
@@ -441,19 +546,24 @@ def test_extract_archive_skips_abspath_for_remote_repository():
     flexmock(module.os.path).should_receive('abspath').never()
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
-        ('borg', 'extract', 'server:repo::archive'), working_directory=None, extra_environment=None,
+        ('borg', 'extract', 'server:repo::archive'),
+        working_directory=None,
+        extra_environment=None,
     ).once()
     flexmock(module.feature).should_receive('available').and_return(True)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
         ('server:repo::archive',)
     )
+    flexmock(module.borgmatic.config.validate).should_receive(
+        'normalize_repository_path'
+    ).and_return('repo')
 
     module.extract_archive(
         dry_run=False,
         repository='server:repo',
         archive='archive',
         paths=None,
-        location_config={},
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
