@@ -27,8 +27,9 @@ def test_display_archives_info_calls_borg_with_parameters():
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
     )
 
@@ -52,8 +53,9 @@ def test_display_archives_info_with_log_info_calls_borg_with_info_parameter():
     insert_logging_mock(logging.INFO)
     module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
     )
 
@@ -69,14 +71,17 @@ def test_display_archives_info_with_log_info_and_json_suppresses_most_borg_outpu
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg', 'info', '--json', '--repo', 'repo'), extra_environment=None,
+        ('borg', 'info', '--json', '--repo', 'repo'),
+        extra_environment=None,
+        borg_local_path='borg',
     ).and_return('[]')
 
     insert_logging_mock(logging.INFO)
     json_output = module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=True, prefix=None, match_archives=None),
     )
 
@@ -103,8 +108,9 @@ def test_display_archives_info_with_log_debug_calls_borg_with_debug_parameter():
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
     )
 
@@ -120,14 +126,17 @@ def test_display_archives_info_with_log_debug_and_json_suppresses_most_borg_outp
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg', 'info', '--json', '--repo', 'repo'), extra_environment=None,
+        ('borg', 'info', '--json', '--repo', 'repo'),
+        extra_environment=None,
+        borg_local_path='borg',
     ).and_return('[]')
 
     insert_logging_mock(logging.DEBUG)
     json_output = module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=True, prefix=None, match_archives=None),
     )
 
@@ -145,13 +154,16 @@ def test_display_archives_info_with_json_calls_borg_with_json_parameter():
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg', 'info', '--json', '--repo', 'repo'), extra_environment=None,
+        ('borg', 'info', '--json', '--repo', 'repo'),
+        extra_environment=None,
+        borg_local_path='borg',
     ).and_return('[]')
 
     json_output = module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=True, prefix=None, match_archives=None),
     )
 
@@ -177,8 +189,9 @@ def test_display_archives_info_with_archive_calls_borg_with_match_archives_param
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive='archive', json=False, prefix=None, match_archives=None),
     )
 
@@ -202,8 +215,9 @@ def test_display_archives_info_with_local_path_calls_borg_via_local_path():
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         local_path='borg1',
     )
@@ -231,13 +245,43 @@ def test_display_archives_info_with_remote_path_calls_borg_with_remote_path_para
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
         remote_path='borg1',
     )
 
 
+def test_display_archives_info_with_log_json_calls_borg_with_log_json_parameters():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags').with_args('log-json', True).and_return(
+        ('--log-json',)
+    )
+    flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
+        None, None, '2.3.4'
+    ).and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module).should_receive('execute_command').with_args(
+        ('borg', 'info', '--log-json', '--repo', 'repo'),
+        output_log_level=module.borgmatic.logger.ANSWER,
+        borg_local_path='borg',
+        extra_environment=None,
+    )
+
+    module.display_archives_info(
+        repository_path='repo',
+        config={},
+        local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=True),
+        info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
+    )
+
+
 def test_display_archives_info_with_lock_wait_calls_borg_with_lock_wait_parameters():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
@@ -250,7 +294,7 @@ def test_display_archives_info_with_lock_wait_calls_borg_with_lock_wait_paramete
     ).and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
-    storage_config = {'lock_wait': 5}
+    config = {'lock_wait': 5}
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
         ('borg', 'info', '--lock-wait', '5', '--repo', 'repo'),
@@ -261,8 +305,9 @@ def test_display_archives_info_with_lock_wait_calls_borg_with_lock_wait_paramete
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config=storage_config,
+        config=config,
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
     )
 
@@ -289,8 +334,9 @@ def test_display_archives_info_transforms_prefix_into_match_archives_parameters(
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix='foo'),
     )
 
@@ -317,8 +363,9 @@ def test_display_archives_info_prefers_prefix_over_archive_name_format():
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix='foo'),
     )
 
@@ -342,8 +389,9 @@ def test_display_archives_info_transforms_archive_name_format_into_match_archive
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
     )
 
@@ -367,11 +415,12 @@ def test_display_archives_with_match_archives_option_calls_borg_with_match_archi
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={
+        config={
             'archive_name_format': 'bar-{now}',  # noqa: FS003
             'match_archives': 'sh:foo-*',
         },
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives=None),
     )
 
@@ -395,8 +444,9 @@ def test_display_archives_with_match_archives_flag_calls_borg_with_match_archive
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(archive=None, json=False, prefix=None, match_archives='sh:foo-*'),
     )
 
@@ -424,9 +474,60 @@ def test_display_archives_info_passes_through_arguments_to_borg(argument_name):
 
     module.display_archives_info(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
         info_arguments=flexmock(
             archive=None, json=False, prefix=None, match_archives=None, **{argument_name: 'value'}
         ),
     )
+
+
+def test_display_archives_info_with_date_based_matching_calls_borg_with_date_based_flags():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
+        None, None, '2.3.4'
+    ).and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(
+        ('--newer', '1d', '--newest', '1y', '--older', '1m', '--oldest', '1w')
+    )
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module).should_receive('execute_command').with_args(
+        (
+            'borg',
+            'info',
+            '--newer',
+            '1d',
+            '--newest',
+            '1y',
+            '--older',
+            '1m',
+            '--oldest',
+            '1w',
+            '--repo',
+            'repo',
+        ),
+        output_log_level=module.borgmatic.logger.ANSWER,
+        borg_local_path='borg',
+        extra_environment=None,
+    )
+    info_arguments = flexmock(
+        archive=None,
+        json=False,
+        prefix=None,
+        match_archives=None,
+        newer='1d',
+        newest='1y',
+        older='1m',
+        oldest='1w',
+    )
+    module.display_archives_info(
+        repository_path='repo',
+        config={},
+        local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
+        info_arguments=info_arguments,
+    )
