@@ -17,9 +17,10 @@ def test_make_list_command_includes_log_info():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive=None, paths=None, json=False),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--info', 'repo')
@@ -33,9 +34,10 @@ def test_make_list_command_includes_json_but_not_info():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive=None, paths=None, json=True),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--json', 'repo')
@@ -49,9 +51,10 @@ def test_make_list_command_includes_log_debug():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive=None, paths=None, json=False),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--debug', '--show-rc', 'repo')
@@ -65,9 +68,10 @@ def test_make_list_command_includes_json_but_not_debug():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive=None, paths=None, json=True),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--json', 'repo')
@@ -80,14 +84,31 @@ def test_make_list_command_includes_json():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive=None, paths=None, json=True),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--json', 'repo')
 
 
+def test_make_list_command_includes_log_json():
+    flexmock(module.flags).should_receive('make_flags').and_return(()).and_return(('--log-json',))
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+
+    command = module.make_list_command(
+        repository_path='repo',
+        config={},
+        local_borg_version='1.2.3',
+        list_arguments=flexmock(archive=None, paths=None, json=False),
+        global_arguments=flexmock(log_json=True),
+    )
+
+    assert command == ('borg', 'list', '--log-json', 'repo')
+
+
 def test_make_list_command_includes_lock_wait():
     flexmock(module.flags).should_receive('make_flags').and_return(()).and_return(
         ('--lock-wait', '5')
@@ -97,9 +118,10 @@ def test_make_list_command_includes_lock_wait():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={'lock_wait': 5},
+        config={'lock_wait': 5},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive=None, paths=None, json=False),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--lock-wait', '5', 'repo')
@@ -114,9 +136,10 @@ def test_make_list_command_includes_archive():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive='archive', paths=None, json=False),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', 'repo::archive')
@@ -131,9 +154,10 @@ def test_make_list_command_includes_archive_and_path():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive='archive', paths=['var/lib'], json=False),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', 'repo::archive', 'var/lib')
@@ -146,9 +170,10 @@ def test_make_list_command_includes_local_path():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive=None, paths=None, json=False),
+        global_arguments=flexmock(log_json=False),
         local_path='borg2',
     )
 
@@ -156,17 +181,22 @@ def test_make_list_command_includes_local_path():
 
 
 def test_make_list_command_includes_remote_path():
-    flexmock(module.flags).should_receive('make_flags').and_return(
-        ('--remote-path', 'borg2')
-    ).and_return(())
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags').with_args(
+        'remote-path', 'borg2'
+    ).and_return(('--remote-path', 'borg2'))
+    flexmock(module.flags).should_receive('make_flags').with_args('log-json', True).and_return(
+        ('--log-json')
+    )
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive=None, paths=None, json=False),
+        global_arguments=flexmock(log_json=False),
         remote_path='borg2',
     )
 
@@ -180,9 +210,10 @@ def test_make_list_command_includes_short():
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(archive=None, paths=None, json=False, short=True),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--short', 'repo')
@@ -211,7 +242,7 @@ def test_make_list_command_includes_additional_flags(argument_name):
 
     command = module.make_list_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=flexmock(
             archive=None,
@@ -221,6 +252,7 @@ def test_make_list_command_includes_additional_flags(argument_name):
             format=None,
             **{argument_name: 'value'},
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--' + argument_name.replace('_', '-'), 'value', 'repo')
@@ -261,12 +293,13 @@ def test_capture_archive_listing_does_not_raise():
     module.capture_archive_listing(
         repository_path='repo',
         archive='archive',
-        storage_config=flexmock(),
+        config=flexmock(),
         local_borg_version=flexmock(),
+        global_arguments=flexmock(log_json=False),
     )
 
 
-def test_list_archive_calls_borg_with_parameters():
+def test_list_archive_calls_borg_with_flags():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.logger).answer = lambda message: None
@@ -281,13 +314,15 @@ def test_list_archive_calls_borg_with_parameters():
         first=None,
         last=None,
     )
+    global_arguments = flexmock(log_json=False)
 
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module).should_receive('make_list_command').with_args(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=list_arguments,
+        global_arguments=global_arguments,
         local_path='borg',
         remote_path=None,
     ).and_return(('borg', 'list', 'repo::archive'))
@@ -302,9 +337,10 @@ def test_list_archive_calls_borg_with_parameters():
 
     module.list_archive(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=list_arguments,
+        global_arguments=global_arguments,
     )
 
 
@@ -319,9 +355,10 @@ def test_list_archive_with_archive_and_json_errors():
     with pytest.raises(ValueError):
         module.list_archive(
             repository_path='repo',
-            storage_config={},
+            config={},
             local_borg_version='1.2.3',
             list_arguments=list_arguments,
+            global_arguments=flexmock(log_json=False),
         )
 
 
@@ -340,13 +377,15 @@ def test_list_archive_calls_borg_with_local_path():
         first=None,
         last=None,
     )
+    global_arguments = flexmock(log_json=False)
 
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module).should_receive('make_list_command').with_args(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=list_arguments,
+        global_arguments=global_arguments,
         local_path='borg2',
         remote_path=None,
     ).and_return(('borg2', 'list', 'repo::archive'))
@@ -361,9 +400,10 @@ def test_list_archive_calls_borg_with_local_path():
 
     module.list_archive(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=list_arguments,
+        global_arguments=global_arguments,
         local_path='borg2',
     )
 
@@ -387,7 +427,9 @@ def test_list_archive_calls_borg_multiple_times_with_find_paths():
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.rlist).should_receive('make_rlist_command').and_return(('borg', 'list', 'repo'))
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg', 'list', 'repo'), extra_environment=None,
+        ('borg', 'list', 'repo'),
+        extra_environment=None,
+        borg_local_path='borg',
     ).and_return('archive1\narchive2').once()
     flexmock(module).should_receive('make_list_command').and_return(
         ('borg', 'list', 'repo::archive1')
@@ -409,9 +451,10 @@ def test_list_archive_calls_borg_multiple_times_with_find_paths():
 
     module.list_archive(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=list_arguments,
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -430,13 +473,15 @@ def test_list_archive_calls_borg_with_archive():
         first=None,
         last=None,
     )
+    global_arguments = flexmock(log_json=False)
 
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module).should_receive('make_list_command').with_args(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=list_arguments,
+        global_arguments=global_arguments,
         local_path='borg',
         remote_path=None,
     ).and_return(('borg', 'list', 'repo::archive'))
@@ -451,9 +496,10 @@ def test_list_archive_calls_borg_with_archive():
 
     module.list_archive(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=list_arguments,
+        global_arguments=global_arguments,
     )
 
 
@@ -481,9 +527,10 @@ def test_list_archive_without_archive_delegates_to_list_repository():
 
     module.list_archive(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=list_arguments,
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -511,19 +558,30 @@ def test_list_archive_with_borg_features_without_archive_delegates_to_list_repos
 
     module.list_archive(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=list_arguments,
+        global_arguments=flexmock(log_json=False),
     )
 
 
 @pytest.mark.parametrize(
-    'archive_filter_flag', ('prefix', 'match_archives', 'sort_by', 'first', 'last',),
+    'archive_filter_flag',
+    (
+        'prefix',
+        'match_archives',
+        'sort_by',
+        'first',
+        'last',
+    ),
 )
-def test_list_archive_with_archive_ignores_archive_filter_flag(archive_filter_flag,):
+def test_list_archive_with_archive_ignores_archive_filter_flag(
+    archive_filter_flag,
+):
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     flexmock(module.logger).answer = lambda message: None
+    global_arguments = flexmock(log_json=False)
     default_filter_flags = {
         'prefix': None,
         'match_archives': None,
@@ -538,11 +596,12 @@ def test_list_archive_with_archive_ignores_archive_filter_flag(archive_filter_fl
     ).and_return(False)
     flexmock(module).should_receive('make_list_command').with_args(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=argparse.Namespace(
             archive='archive', paths=None, json=False, find_paths=None, **default_filter_flags
         ),
+        global_arguments=global_arguments,
         local_path='borg',
         remote_path=None,
     ).and_return(('borg', 'list', 'repo::archive'))
@@ -557,16 +616,24 @@ def test_list_archive_with_archive_ignores_archive_filter_flag(archive_filter_fl
 
     module.list_archive(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=argparse.Namespace(
             archive='archive', paths=None, json=False, find_paths=None, **altered_filter_flags
         ),
+        global_arguments=global_arguments,
     )
 
 
 @pytest.mark.parametrize(
-    'archive_filter_flag', ('prefix', 'match_archives', 'sort_by', 'first', 'last',),
+    'archive_filter_flag',
+    (
+        'prefix',
+        'match_archives',
+        'sort_by',
+        'first',
+        'last',
+    ),
 )
 def test_list_archive_with_find_paths_allows_archive_filter_flag_but_only_passes_it_to_rlist(
     archive_filter_flag,
@@ -583,26 +650,30 @@ def test_list_archive_with_find_paths_allows_archive_filter_flag_but_only_passes
     }
     altered_filter_flags = {**default_filter_flags, **{archive_filter_flag: 'foo'}}
     glob_paths = ('**/*foo.txt*/**',)
+    global_arguments = flexmock(log_json=False)
     flexmock(module.feature).should_receive('available').and_return(True)
 
     flexmock(module.rlist).should_receive('make_rlist_command').with_args(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=argparse.Namespace(
             repository='repo', short=True, format=None, json=None, **altered_filter_flags
         ),
+        global_arguments=global_arguments,
         local_path='borg',
         remote_path=None,
     ).and_return(('borg', 'rlist', '--repo', 'repo'))
 
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg', 'rlist', '--repo', 'repo'), extra_environment=None,
+        ('borg', 'rlist', '--repo', 'repo'),
+        extra_environment=None,
+        borg_local_path='borg',
     ).and_return('archive1\narchive2').once()
 
     flexmock(module).should_receive('make_list_command').with_args(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=argparse.Namespace(
             repository='repo',
@@ -614,13 +685,14 @@ def test_list_archive_with_find_paths_allows_archive_filter_flag_but_only_passes
             find_paths=['foo.txt'],
             **default_filter_flags,
         ),
+        global_arguments=global_arguments,
         local_path='borg',
         remote_path=None,
     ).and_return(('borg', 'list', '--repo', 'repo', 'archive1'))
 
     flexmock(module).should_receive('make_list_command').with_args(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=argparse.Namespace(
             repository='repo',
@@ -632,6 +704,7 @@ def test_list_archive_with_find_paths_allows_archive_filter_flag_but_only_passes
             find_paths=['foo.txt'],
             **default_filter_flags,
         ),
+        global_arguments=global_arguments,
         local_path='borg',
         remote_path=None,
     ).and_return(('borg', 'list', '--repo', 'repo', 'archive2'))
@@ -653,7 +726,7 @@ def test_list_archive_with_find_paths_allows_archive_filter_flag_but_only_passes
 
     module.list_archive(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         list_arguments=argparse.Namespace(
             repository='repo',
@@ -665,4 +738,5 @@ def test_list_archive_with_find_paths_allows_archive_filter_flag_but_only_passes
             find_paths=['foo.txt'],
             **altered_filter_flags,
         ),
+        global_arguments=global_arguments,
     )
