@@ -10,7 +10,9 @@ from ..test_verbosity import insert_logging_mock
 def insert_execute_command_mock(command):
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
-        command, borg_local_path='borg', extra_environment=None,
+        command,
+        borg_local_path='borg',
+        extra_environment=None,
     ).once()
 
 
@@ -19,34 +21,37 @@ def test_mount_archive_calls_borg_with_required_flags():
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
     insert_execute_command_mock(('borg', 'mount', 'repo', '/mnt'))
 
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
         repository_path='repo',
         archive=None,
-        mount_point='/mnt',
-        paths=None,
-        foreground=False,
-        options=None,
-        storage_config={},
+        mount_arguments=mount_arguments,
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
 def test_mount_archive_with_borg_features_calls_borg_with_repository_and_match_archives_flags():
     flexmock(module.feature).should_receive('available').and_return(True)
-    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo',))
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(
+        (
+            '--repo',
+            'repo',
+        )
+    )
     insert_execute_command_mock(
         ('borg', 'mount', '--repo', 'repo', '--match-archives', 'archive', '/mnt')
     )
 
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
         repository_path='repo',
         archive='archive',
-        mount_point='/mnt',
-        paths=None,
-        foreground=False,
-        options=None,
-        storage_config={},
+        mount_arguments=mount_arguments,
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -57,15 +62,14 @@ def test_mount_archive_without_archive_calls_borg_with_repository_flags_only():
     )
     insert_execute_command_mock(('borg', 'mount', 'repo::archive', '/mnt'))
 
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
         repository_path='repo',
         archive='archive',
-        mount_point='/mnt',
-        paths=None,
-        foreground=False,
-        options=None,
-        storage_config={},
+        mount_arguments=mount_arguments,
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -76,15 +80,16 @@ def test_mount_archive_calls_borg_with_path_flags():
     )
     insert_execute_command_mock(('borg', 'mount', 'repo::archive', '/mnt', 'path1', 'path2'))
 
+    mount_arguments = flexmock(
+        mount_point='/mnt', options=None, paths=['path1', 'path2'], foreground=False
+    )
     module.mount_archive(
         repository_path='repo',
         archive='archive',
-        mount_point='/mnt',
-        paths=['path1', 'path2'],
-        foreground=False,
-        options=None,
-        storage_config={},
+        mount_arguments=mount_arguments,
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -97,15 +102,14 @@ def test_mount_archive_calls_borg_with_remote_path_flags():
         ('borg', 'mount', '--remote-path', 'borg1', 'repo::archive', '/mnt')
     )
 
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
         repository_path='repo',
         archive='archive',
-        mount_point='/mnt',
-        paths=None,
-        foreground=False,
-        options=None,
-        storage_config={},
+        mount_arguments=mount_arguments,
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
         remote_path='borg1',
     )
 
@@ -117,15 +121,32 @@ def test_mount_archive_calls_borg_with_umask_flags():
     )
     insert_execute_command_mock(('borg', 'mount', '--umask', '0770', 'repo::archive', '/mnt'))
 
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
         repository_path='repo',
         archive='archive',
-        mount_point='/mnt',
-        paths=None,
-        foreground=False,
-        options=None,
-        storage_config={'umask': '0770'},
+        mount_arguments=mount_arguments,
+        config={'umask': '0770'},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+    )
+
+
+def test_mount_archive_calls_borg_with_log_json_flags():
+    flexmock(module.feature).should_receive('available').and_return(False)
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',)
+    )
+    insert_execute_command_mock(('borg', 'mount', '--log-json', 'repo::archive', '/mnt'))
+
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
+    module.mount_archive(
+        repository_path='repo',
+        archive='archive',
+        mount_arguments=mount_arguments,
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=True),
     )
 
 
@@ -136,15 +157,14 @@ def test_mount_archive_calls_borg_with_lock_wait_flags():
     )
     insert_execute_command_mock(('borg', 'mount', '--lock-wait', '5', 'repo::archive', '/mnt'))
 
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
         repository_path='repo',
         archive='archive',
-        mount_point='/mnt',
-        paths=None,
-        foreground=False,
-        options=None,
-        storage_config={'lock_wait': '5'},
+        mount_arguments=mount_arguments,
+        config={'lock_wait': '5'},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -156,15 +176,14 @@ def test_mount_archive_with_log_info_calls_borg_with_info_parameter():
     insert_execute_command_mock(('borg', 'mount', '--info', 'repo::archive', '/mnt'))
     insert_logging_mock(logging.INFO)
 
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
         repository_path='repo',
         archive='archive',
-        mount_point='/mnt',
-        paths=None,
-        foreground=False,
-        options=None,
-        storage_config={},
+        mount_arguments=mount_arguments,
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -176,15 +195,14 @@ def test_mount_archive_with_log_debug_calls_borg_with_debug_flags():
     insert_execute_command_mock(('borg', 'mount', '--debug', '--show-rc', 'repo::archive', '/mnt'))
     insert_logging_mock(logging.DEBUG)
 
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
     module.mount_archive(
         repository_path='repo',
         archive='archive',
-        mount_point='/mnt',
-        paths=None,
-        foreground=False,
-        options=None,
-        storage_config={},
+        mount_arguments=mount_arguments,
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -201,15 +219,14 @@ def test_mount_archive_calls_borg_with_foreground_parameter():
         extra_environment=None,
     ).once()
 
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=True)
     module.mount_archive(
         repository_path='repo',
         archive='archive',
-        mount_point='/mnt',
-        paths=None,
-        foreground=True,
-        options=None,
-        storage_config={},
+        mount_arguments=mount_arguments,
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -220,13 +237,75 @@ def test_mount_archive_calls_borg_with_options_flags():
     )
     insert_execute_command_mock(('borg', 'mount', '-o', 'super_mount', 'repo::archive', '/mnt'))
 
+    mount_arguments = flexmock(
+        mount_point='/mnt', options='super_mount', paths=None, foreground=False
+    )
     module.mount_archive(
         repository_path='repo',
         archive='archive',
+        mount_arguments=mount_arguments,
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+    )
+
+
+def test_mount_archive_with_date_based_matching_calls_borg_with_date_based_flags():
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(
+        (
+            '--newer',
+            '1d',
+            '--newest',
+            '1y',
+            '--older',
+            '1m',
+            '--oldest',
+            '1w',
+            '--match-archives',
+            None,
+        )
+    )
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module).should_receive('execute_command').with_args(
+        (
+            'borg',
+            'mount',
+            '--newer',
+            '1d',
+            '--newest',
+            '1y',
+            '--older',
+            '1m',
+            '--oldest',
+            '1w',
+            '--match-archives',
+            None,
+            '--repo',
+            'repo',
+            '/mnt',
+        ),
+        borg_local_path='borg',
+        extra_environment=None,
+    )
+
+    mount_arguments = flexmock(
         mount_point='/mnt',
+        options=None,
         paths=None,
         foreground=False,
-        options='super_mount',
-        storage_config={},
+        newer='1d',
+        newest='1y',
+        older='1m',
+        oldest='1w',
+    )
+    module.mount_archive(
+        repository_path='repo',
+        archive=None,
+        mount_arguments=mount_arguments,
+        config={},
         local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
     )
