@@ -20,48 +20,78 @@ def test_resolve_archive_name_passes_through_non_latest_archive_name():
     archive = 'myhost-2030-01-01T14:41:17.647620'
 
     assert (
-        module.resolve_archive_name('repo', archive, storage_config={}, local_borg_version='1.2.3')
+        module.resolve_archive_name(
+            'repo',
+            archive,
+            config={},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
+        )
         == archive
     )
 
 
-def test_resolve_archive_name_calls_borg_with_parameters():
+def test_resolve_archive_name_calls_borg_with_flags():
     expected_archive = 'archive-name'
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg', 'list') + BORG_LIST_LATEST_ARGUMENTS, extra_environment=None,
+        ('borg', 'list') + BORG_LIST_LATEST_ARGUMENTS,
+        extra_environment=None,
+        borg_local_path='borg',
     ).and_return(expected_archive + '\n')
 
     assert (
-        module.resolve_archive_name('repo', 'latest', storage_config={}, local_borg_version='1.2.3')
+        module.resolve_archive_name(
+            'repo',
+            'latest',
+            config={},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
+        )
         == expected_archive
     )
 
 
-def test_resolve_archive_name_with_log_info_calls_borg_without_info_parameter():
+def test_resolve_archive_name_with_log_info_calls_borg_without_info_flag():
     expected_archive = 'archive-name'
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg', 'list') + BORG_LIST_LATEST_ARGUMENTS, extra_environment=None,
+        ('borg', 'list') + BORG_LIST_LATEST_ARGUMENTS,
+        extra_environment=None,
+        borg_local_path='borg',
     ).and_return(expected_archive + '\n')
     insert_logging_mock(logging.INFO)
 
     assert (
-        module.resolve_archive_name('repo', 'latest', storage_config={}, local_borg_version='1.2.3')
+        module.resolve_archive_name(
+            'repo',
+            'latest',
+            config={},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
+        )
         == expected_archive
     )
 
 
-def test_resolve_archive_name_with_log_debug_calls_borg_without_debug_parameter():
+def test_resolve_archive_name_with_log_debug_calls_borg_without_debug_flag():
     expected_archive = 'archive-name'
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg', 'list') + BORG_LIST_LATEST_ARGUMENTS, extra_environment=None,
+        ('borg', 'list') + BORG_LIST_LATEST_ARGUMENTS,
+        extra_environment=None,
+        borg_local_path='borg',
     ).and_return(expected_archive + '\n')
     insert_logging_mock(logging.DEBUG)
 
     assert (
-        module.resolve_archive_name('repo', 'latest', storage_config={}, local_borg_version='1.2.3')
+        module.resolve_archive_name(
+            'repo',
+            'latest',
+            config={},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
+        )
         == expected_archive
     )
 
@@ -70,28 +100,41 @@ def test_resolve_archive_name_with_local_path_calls_borg_via_local_path():
     expected_archive = 'archive-name'
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg1', 'list') + BORG_LIST_LATEST_ARGUMENTS, extra_environment=None,
+        ('borg1', 'list') + BORG_LIST_LATEST_ARGUMENTS,
+        extra_environment=None,
+        borg_local_path='borg1',
     ).and_return(expected_archive + '\n')
 
     assert (
         module.resolve_archive_name(
-            'repo', 'latest', storage_config={}, local_borg_version='1.2.3', local_path='borg1'
+            'repo',
+            'latest',
+            config={},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
+            local_path='borg1',
         )
         == expected_archive
     )
 
 
-def test_resolve_archive_name_with_remote_path_calls_borg_with_remote_path_parameters():
+def test_resolve_archive_name_with_remote_path_calls_borg_with_remote_path_flags():
     expected_archive = 'archive-name'
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         ('borg', 'list', '--remote-path', 'borg1') + BORG_LIST_LATEST_ARGUMENTS,
         extra_environment=None,
+        borg_local_path='borg',
     ).and_return(expected_archive + '\n')
 
     assert (
         module.resolve_archive_name(
-            'repo', 'latest', storage_config={}, local_borg_version='1.2.3', remote_path='borg1'
+            'repo',
+            'latest',
+            config={},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
+            remote_path='borg1',
         )
         == expected_archive
     )
@@ -100,25 +143,60 @@ def test_resolve_archive_name_with_remote_path_calls_borg_with_remote_path_param
 def test_resolve_archive_name_without_archives_raises():
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        ('borg', 'list') + BORG_LIST_LATEST_ARGUMENTS, extra_environment=None,
+        ('borg', 'list') + BORG_LIST_LATEST_ARGUMENTS,
+        extra_environment=None,
+        borg_local_path='borg',
     ).and_return('')
 
     with pytest.raises(ValueError):
-        module.resolve_archive_name('repo', 'latest', storage_config={}, local_borg_version='1.2.3')
+        module.resolve_archive_name(
+            'repo',
+            'latest',
+            config={},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
+        )
 
 
-def test_resolve_archive_name_with_lock_wait_calls_borg_with_lock_wait_parameters():
+def test_resolve_archive_name_with_log_json_calls_borg_with_log_json_flags():
+    expected_archive = 'archive-name'
+
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module).should_receive('execute_command_and_capture_output').with_args(
+        ('borg', 'list', '--log-json') + BORG_LIST_LATEST_ARGUMENTS,
+        extra_environment=None,
+        borg_local_path='borg',
+    ).and_return(expected_archive + '\n')
+
+    assert (
+        module.resolve_archive_name(
+            'repo',
+            'latest',
+            config={},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=True),
+        )
+        == expected_archive
+    )
+
+
+def test_resolve_archive_name_with_lock_wait_calls_borg_with_lock_wait_flags():
     expected_archive = 'archive-name'
 
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
         ('borg', 'list', '--lock-wait', 'okay') + BORG_LIST_LATEST_ARGUMENTS,
         extra_environment=None,
+        borg_local_path='borg',
     ).and_return(expected_archive + '\n')
 
     assert (
         module.resolve_archive_name(
-            'repo', 'latest', storage_config={'lock_wait': 'okay'}, local_borg_version='1.2.3'
+            'repo',
+            'latest',
+            config={'lock_wait': 'okay'},
+            local_borg_version='1.2.3',
+            global_arguments=flexmock(log_json=False),
         )
         == expected_archive
     )
@@ -135,11 +213,12 @@ def test_make_rlist_command_includes_log_info():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=False, prefix=None, match_archives=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--info', 'repo')
@@ -156,11 +235,12 @@ def test_make_rlist_command_includes_json_but_not_info():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=True, prefix=None, match_archives=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--json', 'repo')
@@ -177,11 +257,12 @@ def test_make_rlist_command_includes_log_debug():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=False, prefix=None, match_archives=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--debug', '--show-rc', 'repo')
@@ -198,11 +279,12 @@ def test_make_rlist_command_includes_json_but_not_debug():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=True, prefix=None, match_archives=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--json', 'repo')
@@ -218,16 +300,40 @@ def test_make_rlist_command_includes_json():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=True, prefix=None, match_archives=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--json', 'repo')
 
 
+def test_make_rlist_command_includes_log_json():
+    flexmock(module.flags).should_receive('make_flags').and_return(()).and_return(
+        ('--log-json',)
+    ).and_return(())
+    flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
+        None, None, '1.2.3'
+    ).and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+
+    command = module.make_rlist_command(
+        repository_path='repo',
+        config={},
+        local_borg_version='1.2.3',
+        rlist_arguments=flexmock(
+            archive=None, paths=None, json=False, prefix=None, match_archives=None
+        ),
+        global_arguments=flexmock(log_json=True),
+    )
+
+    assert command == ('borg', 'list', '--log-json', 'repo')
+
+
 def test_make_rlist_command_includes_lock_wait():
     flexmock(module.flags).should_receive('make_flags').and_return(()).and_return(
         ('--lock-wait', '5')
@@ -240,11 +346,12 @@ def test_make_rlist_command_includes_lock_wait():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={'lock_wait': 5},
+        config={'lock_wait': 5},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=False, prefix=None, match_archives=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--lock-wait', '5', 'repo')
@@ -260,11 +367,12 @@ def test_make_rlist_command_includes_local_path():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=False, prefix=None, match_archives=None
         ),
+        global_arguments=flexmock(log_json=False),
         local_path='borg2',
     )
 
@@ -283,11 +391,12 @@ def test_make_rlist_command_includes_remote_path():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=False, prefix=None, match_archives=None
         ),
+        global_arguments=flexmock(log_json=False),
         remote_path='borg2',
     )
 
@@ -306,9 +415,10 @@ def test_make_rlist_command_transforms_prefix_into_match_archives():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(archive=None, paths=None, json=False, prefix='foo'),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--match-archives', 'sh:foo*', 'repo')
@@ -324,9 +434,10 @@ def test_make_rlist_command_prefers_prefix_over_archive_name_format():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(archive=None, paths=None, json=False, prefix='foo'),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--match-archives', 'sh:foo*', 'repo')
@@ -342,11 +453,12 @@ def test_make_rlist_command_transforms_archive_name_format_into_match_archives()
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=False, prefix=None, match_archives=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--match-archives', 'sh:bar-*', 'repo')
@@ -362,11 +474,12 @@ def test_make_rlist_command_includes_short():
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None, paths=None, json=False, prefix=None, match_archives=None, short=True
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--short', 'repo')
@@ -374,7 +487,15 @@ def test_make_rlist_command_includes_short():
 
 @pytest.mark.parametrize(
     'argument_name',
-    ('sort_by', 'first', 'last', 'exclude', 'exclude_from', 'pattern', 'patterns_from',),
+    (
+        'sort_by',
+        'first',
+        'last',
+        'exclude',
+        'exclude_from',
+        'pattern',
+        'patterns_from',
+    ),
 )
 def test_make_rlist_command_includes_additional_flags(argument_name):
     flexmock(module.flags).should_receive('make_flags').and_return(())
@@ -388,7 +509,7 @@ def test_make_rlist_command_includes_additional_flags(argument_name):
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None,
@@ -400,25 +521,28 @@ def test_make_rlist_command_includes_additional_flags(argument_name):
             format=None,
             **{argument_name: 'value'},
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--' + argument_name.replace('_', '-'), 'value', 'repo')
 
 
-def test_make_rlist_command_with_match_archives_calls_borg_with_match_archives_parameters():
+def test_make_rlist_command_with_match_archives_calls_borg_with_match_archives_flags():
     flexmock(module.flags).should_receive('make_flags').and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
         None, None, '1.2.3'
     ).and_return(())
     flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
-        'foo-*', None, '1.2.3',
+        'foo-*',
+        None,
+        '1.2.3',
     ).and_return(('--match-archives', 'foo-*'))
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
 
     command = module.make_rlist_command(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=flexmock(
             archive=None,
@@ -429,22 +553,25 @@ def test_make_rlist_command_with_match_archives_calls_borg_with_match_archives_p
             find_paths=None,
             format=None,
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
     assert command == ('borg', 'list', '--match-archives', 'foo-*', 'repo')
 
 
-def test_list_repository_calls_borg_with_parameters():
+def test_list_repository_calls_borg_with_flags():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     rlist_arguments = argparse.Namespace(json=False)
+    global_arguments = flexmock()
 
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module).should_receive('make_rlist_command').with_args(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=rlist_arguments,
+        global_arguments=global_arguments,
         local_path='borg',
         remote_path=None,
     ).and_return(('borg', 'rlist', 'repo'))
@@ -458,9 +585,10 @@ def test_list_repository_calls_borg_with_parameters():
 
     module.list_repository(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=rlist_arguments,
+        global_arguments=global_arguments,
     )
 
 
@@ -468,14 +596,16 @@ def test_list_repository_with_json_returns_borg_output():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
     rlist_arguments = argparse.Namespace(json=True)
+    global_arguments = flexmock()
     json_output = flexmock()
 
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module).should_receive('make_rlist_command').with_args(
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='1.2.3',
         rlist_arguments=rlist_arguments,
+        global_arguments=global_arguments,
         local_path='borg',
         remote_path=None,
     ).and_return(('borg', 'rlist', 'repo'))
@@ -485,9 +615,53 @@ def test_list_repository_with_json_returns_borg_output():
     assert (
         module.list_repository(
             repository_path='repo',
-            storage_config={},
+            config={},
             local_borg_version='1.2.3',
             rlist_arguments=rlist_arguments,
+            global_arguments=global_arguments,
         )
         == json_output
     )
+
+
+def test_make_rlist_command_with_date_based_matching_calls_borg_with_date_based_flags():
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_match_archives_flags').with_args(
+        None, None, '1.2.3'
+    ).and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(
+        ('--newer', '1d', '--newest', '1y', '--older', '1m', '--oldest', '1w')
+    )
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('repo',))
+
+    command = module.make_rlist_command(
+        repository_path='repo',
+        config={},
+        local_borg_version='1.2.3',
+        rlist_arguments=flexmock(
+            archive=None,
+            paths=None,
+            json=False,
+            prefix=None,
+            match_archives=None,
+            newer='1d',
+            newest='1y',
+            older='1m',
+            oldest='1w',
+        ),
+        global_arguments=flexmock(log_json=False),
+    )
+
+    assert command == (
+        'borg',
+        'list',
+        '--newer',
+        '1d',
+        '--newest',
+        '1y',
+        '--older',
+        '1m',
+        '--oldest',
+        '1w',
+        'repo',
+    )
