@@ -27,11 +27,12 @@ def test_transfer_archives_calls_borg_with_flags():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -57,11 +58,12 @@ def test_transfer_archives_with_dry_run_calls_borg_with_dry_run_flag():
     module.transfer_archives(
         dry_run=True,
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -84,11 +86,12 @@ def test_transfer_archives_with_log_info_calls_borg_with_info_flag():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -112,11 +115,12 @@ def test_transfer_archives_with_log_debug_calls_borg_with_debug_flag():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -141,11 +145,12 @@ def test_transfer_archives_with_archive_calls_borg_with_match_archives_flag():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive='archive', progress=None, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -170,11 +175,12 @@ def test_transfer_archives_with_match_archives_calls_borg_with_match_archives_fl
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives='sh:foo*', source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -199,11 +205,12 @@ def test_transfer_archives_with_archive_name_format_calls_borg_with_match_archiv
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
+        config={'archive_name_format': 'bar-{now}'},  # noqa: FS003
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -226,11 +233,12 @@ def test_transfer_archives_with_local_path_calls_borg_via_local_path():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
         local_path='borg2',
     )
 
@@ -257,15 +265,47 @@ def test_transfer_archives_with_remote_path_calls_borg_with_remote_path_flags():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
         remote_path='borg2',
     )
 
 
+def test_transfer_archives_with_log_json_calls_borg_with_log_json_flags():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags').with_args('log-json', True).and_return(
+        ('--log-json',)
+    )
+    flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module).should_receive('execute_command').with_args(
+        ('borg', 'transfer', '--log-json', '--repo', 'repo'),
+        output_log_level=module.borgmatic.logger.ANSWER,
+        output_file=None,
+        borg_local_path='borg',
+        extra_environment=None,
+    )
+
+    module.transfer_archives(
+        dry_run=False,
+        repository_path='repo',
+        config={},
+        local_borg_version='2.3.4',
+        transfer_arguments=flexmock(
+            archive=None, progress=None, match_archives=None, source_repository=None
+        ),
+        global_arguments=flexmock(log_json=True),
+    )
+
+
 def test_transfer_archives_with_lock_wait_calls_borg_with_lock_wait_flags():
     flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
     flexmock(module.logging).ANSWER = module.borgmatic.logger.ANSWER
@@ -276,7 +316,7 @@ def test_transfer_archives_with_lock_wait_calls_borg_with_lock_wait_flags():
     flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
     flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(())
     flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
-    storage_config = {'lock_wait': 5}
+    config = {'lock_wait': 5}
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
         ('borg', 'transfer', '--lock-wait', '5', '--repo', 'repo'),
@@ -289,11 +329,12 @@ def test_transfer_archives_with_lock_wait_calls_borg_with_lock_wait_flags():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config=storage_config,
+        config=config,
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -316,11 +357,12 @@ def test_transfer_archives_with_progress_calls_borg_with_progress_flag():
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=True, match_archives=None, source_repository=None
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -347,7 +389,7 @@ def test_transfer_archives_passes_through_arguments_to_borg(argument_name):
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None,
@@ -356,6 +398,7 @@ def test_transfer_archives_passes_through_arguments_to_borg(argument_name):
             source_repository=None,
             **{argument_name: 'value'},
         ),
+        global_arguments=flexmock(log_json=False),
     )
 
 
@@ -380,9 +423,58 @@ def test_transfer_archives_with_source_repository_calls_borg_with_other_repo_fla
     module.transfer_archives(
         dry_run=False,
         repository_path='repo',
-        storage_config={},
+        config={},
         local_borg_version='2.3.4',
         transfer_arguments=flexmock(
             archive=None, progress=None, match_archives=None, source_repository='other'
         ),
+        global_arguments=flexmock(log_json=False),
+    )
+
+
+def test_transfer_archives_with_date_based_matching_calls_borg_with_date_based_flags():
+    flexmock(module.borgmatic.logger).should_receive('add_custom_log_levels')
+    flexmock(module.flags).should_receive('make_flags').and_return(())
+    flexmock(module.flags).should_receive('make_match_archives_flags').and_return(())
+    flexmock(module.flags).should_receive('make_flags_from_arguments').and_return(
+        ('--newer', '1d', '--newest', '1y', '--older', '1m', '--oldest', '1w')
+    )
+    flexmock(module.flags).should_receive('make_repository_flags').and_return(('--repo', 'repo'))
+    flexmock(module.environment).should_receive('make_environment')
+    flexmock(module).should_receive('execute_command').with_args(
+        (
+            'borg',
+            'transfer',
+            '--newer',
+            '1d',
+            '--newest',
+            '1y',
+            '--older',
+            '1m',
+            '--oldest',
+            '1w',
+            '--repo',
+            'repo',
+        ),
+        output_log_level=module.borgmatic.logger.ANSWER,
+        output_file=None,
+        borg_local_path='borg',
+        extra_environment=None,
+    )
+
+    module.transfer_archives(
+        dry_run=False,
+        repository_path='repo',
+        config={},
+        local_borg_version='2.3.4',
+        global_arguments=flexmock(log_json=False),
+        transfer_arguments=flexmock(
+            archive=None,
+            progress=None,
+            source_repository='other',
+            newer='1d',
+            newest='1y',
+            older='1m',
+            oldest='1w',
+        ),
     )
