@@ -15,7 +15,9 @@ def insert_execute_command_and_capture_output_mock(
 ):
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command_and_capture_output').with_args(
-        command, extra_environment=None,
+        command,
+        extra_environment=None,
+        borg_local_path=borg_local_path,
     ).once().and_return(version_output)
 
 
