@@ -748,6 +748,24 @@ def test_run_actions_runs_break_lock():
     )
 
 
+def test_run_actions_runs_export_key():
+    flexmock(module).should_receive('add_custom_log_levels')
+    flexmock(module.command).should_receive('execute_hook')
+    flexmock(borgmatic.actions.export_key).should_receive('run_export_key').once()
+
+    tuple(
+        module.run_actions(
+            arguments={'global': flexmock(dry_run=False, log_file='foo'), 'export': flexmock()},
+            config_filename=flexmock(),
+            config={'repositories': []},
+            local_path=flexmock(),
+            remote_path=flexmock(),
+            local_borg_version=flexmock(),
+            repository={'path': 'repo'},
+        )
+    )
+
+
 def test_run_actions_runs_borg():
     flexmock(module).should_receive('add_custom_log_levels')
     flexmock(module.command).should_receive('execute_hook')
@@ -831,7 +849,7 @@ def test_log_record_with_suppress_does_not_raise():
 
 
 def test_log_error_records_generates_output_logs_for_message_only():
-    flexmock(module).should_receive('log_record').replace_with(dict)
+    flexmock(module).should_receive('log_record').replace_with(dict).once()
 
     logs = tuple(module.log_error_records('Error'))
 
@@ -839,7 +857,7 @@ def test_log_error_records_generates_output_logs_for_message_only():
 
 
 def test_log_error_records_generates_output_logs_for_called_process_error_with_bytes_ouput():
-    flexmock(module).should_receive('log_record').replace_with(dict)
+    flexmock(module).should_receive('log_record').replace_with(dict).times(3)
     flexmock(module.logger).should_receive('getEffectiveLevel').and_return(logging.WARNING)
 
     logs = tuple(
@@ -851,7 +869,7 @@ def test_log_error_records_generates_output_logs_for_called_process_error_with_b
 
 
 def test_log_error_records_generates_output_logs_for_called_process_error_with_string_ouput():
-    flexmock(module).should_receive('log_record').replace_with(dict)
+    flexmock(module).should_receive('log_record').replace_with(dict).times(3)
     flexmock(module.logger).should_receive('getEffectiveLevel').and_return(logging.WARNING)
 
     logs = tuple(
@@ -862,8 +880,22 @@ def test_log_error_records_generates_output_logs_for_called_process_error_with_s
     assert any(log for log in logs if 'error output' in str(log))
 
 
+def test_log_error_records_splits_called_process_error_with_multiline_ouput_into_multiple_logs():
+    flexmock(module).should_receive('log_record').replace_with(dict).times(4)
+    flexmock(module.logger).should_receive('getEffectiveLevel').and_return(logging.WARNING)
+
+    logs = tuple(
+        module.log_error_records(
+            'Error', subprocess.CalledProcessError(1, 'ls', 'error output\nanother line')
+        )
+    )
+
+    assert {log['levelno'] for log in logs} == {logging.CRITICAL}
+    assert any(log for log in logs if 'error output' in str(log))
+
+
 def test_log_error_records_generates_logs_for_value_error():
-    flexmock(module).should_receive('log_record').replace_with(dict)
+    flexmock(module).should_receive('log_record').replace_with(dict).twice()
 
     logs = tuple(module.log_error_records('Error', ValueError()))
 
@@ -871,7 +903,7 @@ def test_log_error_records_generates_logs_for_value_error():
 
 
 def test_log_error_records_generates_logs_for_os_error():
-    flexmock(module).should_receive('log_record').replace_with(dict)
+    flexmock(module).should_receive('log_record').replace_with(dict).twice()
 
     logs = tuple(module.log_error_records('Error', OSError()))
 
@@ -879,7 +911,7 @@ def test_log_error_records_generates_logs_for_os_error():
 
 
 def test_log_error_records_generates_nothing_for_other_error():
-    flexmock(module).should_receive('log_record').replace_with(dict)
+    flexmock(module).should_receive('log_record').never()
 
     logs = tuple(module.log_error_records('Error', KeyError()))
 
