@@ -11,6 +11,7 @@ def test_ping_monitor_rewrites_ping_url_for_start_state():
 
     module.ping_monitor(
         hook_config,
+        {},
         'config.yaml',
         module.monitor.State.START,
         monitoring_log_level=1,
@@ -26,6 +27,7 @@ def test_ping_monitor_rewrites_ping_url_and_state_for_start_state():
 
     module.ping_monitor(
         hook_config,
+        {},
         'config.yaml',
         module.monitor.State.START,
         monitoring_log_level=1,
@@ -41,6 +43,7 @@ def test_ping_monitor_rewrites_ping_url_for_finish_state():
 
     module.ping_monitor(
         hook_config,
+        {},
         'config.yaml',
         module.monitor.State.FINISH,
         monitoring_log_level=1,
@@ -55,7 +58,12 @@ def test_ping_monitor_rewrites_ping_url_for_fail_state():
     ).and_return(flexmock(ok=True))
 
     module.ping_monitor(
-        hook_config, 'config.yaml', module.monitor.State.FAIL, monitoring_log_level=1, dry_run=False
+        hook_config,
+        {},
+        'config.yaml',
+        module.monitor.State.FAIL,
+        monitoring_log_level=1,
+        dry_run=False,
     )
 
 
@@ -64,7 +72,12 @@ def test_ping_monitor_dry_run_does_not_hit_ping_url():
     flexmock(module.requests).should_receive('get').never()
 
     module.ping_monitor(
-        hook_config, 'config.yaml', module.monitor.State.START, monitoring_log_level=1, dry_run=True
+        hook_config,
+        {},
+        'config.yaml',
+        module.monitor.State.START,
+        monitoring_log_level=1,
+        dry_run=True,
     )
 
 
@@ -77,6 +90,7 @@ def test_ping_monitor_with_connection_error_logs_warning():
 
     module.ping_monitor(
         hook_config,
+        (),
         'config.yaml',
         module.monitor.State.START,
         monitoring_log_level=1,
@@ -97,6 +111,7 @@ def test_ping_monitor_with_other_error_logs_warning():
 
     module.ping_monitor(
         hook_config,
+        {},
         'config.yaml',
         module.monitor.State.START,
         monitoring_log_level=1,
@@ -104,9 +119,15 @@ def test_ping_monitor_with_other_error_logs_warning():
     )
 
 
-def test_ping_monitor_with_unsupported_monitoring_state():
+def test_ping_monitor_with_unsupported_monitoring_state_bails():
     hook_config = {'ping_url': 'https://example.com'}
     flexmock(module.requests).should_receive('get').never()
+
     module.ping_monitor(
-        hook_config, 'config.yaml', module.monitor.State.LOG, monitoring_log_level=1, dry_run=False,
+        hook_config,
+        {},
+        'config.yaml',
+        module.monitor.State.LOG,
+        monitoring_log_level=1,
+        dry_run=False,
     )
