@@ -1,53 +1,52 @@
 import logging
 
-import pytest
 from flexmock import flexmock
 
 from borgmatic.hooks import mongodb as module
 
 
-def test_dump_databases_runs_mongodump_for_each_database():
+def test_dump_data_sources_runs_mongodump_for_each_database():
     databases = [{'name': 'foo'}, {'name': 'bar'}]
     processes = [flexmock(), flexmock()]
     flexmock(module).should_receive('make_dump_path').and_return('')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return(
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
         'databases/localhost/foo'
     ).and_return('databases/localhost/bar')
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
     for name, process in zip(('foo', 'bar'), processes):
         flexmock(module).should_receive('execute_command').with_args(
-            ['mongodump', '--db', name, '--archive', '>', f'databases/localhost/{name}'],
+            ('mongodump', '--db', name, '--archive', '>', f'databases/localhost/{name}'),
             shell=True,
             run_to_completion=False,
         ).and_return(process).once()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False) == processes
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == processes
 
 
-def test_dump_databases_with_dry_run_skips_mongodump():
+def test_dump_data_sources_with_dry_run_skips_mongodump():
     databases = [{'name': 'foo'}, {'name': 'bar'}]
     flexmock(module).should_receive('make_dump_path').and_return('')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return(
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
         'databases/localhost/foo'
     ).and_return('databases/localhost/bar')
     flexmock(module.dump).should_receive('create_named_pipe_for_dump').never()
     flexmock(module).should_receive('execute_command').never()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=True) == []
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=True) == []
 
 
-def test_dump_databases_runs_mongodump_with_hostname_and_port():
+def test_dump_data_sources_runs_mongodump_with_hostname_and_port():
     databases = [{'name': 'foo', 'hostname': 'database.example.org', 'port': 5433}]
     process = flexmock()
     flexmock(module).should_receive('make_dump_path').and_return('')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return(
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
         'databases/database.example.org/foo'
     )
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
     flexmock(module).should_receive('execute_command').with_args(
-        [
+        (
             'mongodump',
             '--host',
             'database.example.org',
@@ -58,15 +57,15 @@ def test_dump_databases_runs_mongodump_with_hostname_and_port():
             '--archive',
             '>',
             'databases/database.example.org/foo',
-        ],
+        ),
         shell=True,
         run_to_completion=False,
     ).and_return(process).once()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
 
 
-def test_dump_databases_runs_mongodump_with_username_and_password():
+def test_dump_data_sources_runs_mongodump_with_username_and_password():
     databases = [
         {
             'name': 'foo',
@@ -77,13 +76,13 @@ def test_dump_databases_runs_mongodump_with_username_and_password():
     ]
     process = flexmock()
     flexmock(module).should_receive('make_dump_path').and_return('')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return(
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
         'databases/localhost/foo'
     )
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
     flexmock(module).should_receive('execute_command').with_args(
-        [
+        (
             'mongodump',
             '--username',
             'mongo',
@@ -96,85 +95,93 @@ def test_dump_databases_runs_mongodump_with_username_and_password():
             '--archive',
             '>',
             'databases/localhost/foo',
-        ],
+        ),
         shell=True,
         run_to_completion=False,
     ).and_return(process).once()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
 
 
-def test_dump_databases_runs_mongodump_with_directory_format():
+def test_dump_data_sources_runs_mongodump_with_directory_format():
     databases = [{'name': 'foo', 'format': 'directory'}]
     flexmock(module).should_receive('make_dump_path').and_return('')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return(
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
         'databases/localhost/foo'
     )
     flexmock(module.dump).should_receive('create_parent_directory_for_dump')
     flexmock(module.dump).should_receive('create_named_pipe_for_dump').never()
 
     flexmock(module).should_receive('execute_command').with_args(
-        ['mongodump', '--out', 'databases/localhost/foo', '--db', 'foo'],
+        ('mongodump', '--out', 'databases/localhost/foo', '--db', 'foo'),
         shell=True,
     ).and_return(flexmock()).once()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False) == []
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == []
 
 
-def test_dump_databases_runs_mongodump_with_options():
+def test_dump_data_sources_runs_mongodump_with_options():
     databases = [{'name': 'foo', 'options': '--stuff=such'}]
     process = flexmock()
     flexmock(module).should_receive('make_dump_path').and_return('')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return(
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
         'databases/localhost/foo'
     )
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
     flexmock(module).should_receive('execute_command').with_args(
-        ['mongodump', '--db', 'foo', '--stuff=such', '--archive', '>', 'databases/localhost/foo'],
+        (
+            'mongodump',
+            '--db',
+            'foo',
+            '--stuff=such',
+            '--archive',
+            '>',
+            'databases/localhost/foo',
+        ),
         shell=True,
         run_to_completion=False,
     ).and_return(process).once()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
 
 
-def test_dump_databases_runs_mongodumpall_for_all_databases():
+def test_dump_data_sources_runs_mongodumpall_for_all_databases():
     databases = [{'name': 'all'}]
     process = flexmock()
     flexmock(module).should_receive('make_dump_path').and_return('')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return(
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
         'databases/localhost/all'
     )
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
     flexmock(module).should_receive('execute_command').with_args(
-        ['mongodump', '--archive', '>', 'databases/localhost/all'],
+        ('mongodump', '--archive', '>', 'databases/localhost/all'),
         shell=True,
         run_to_completion=False,
     ).and_return(process).once()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
 
 
-def test_restore_database_dump_runs_mongorestore():
-    databases_config = [{'name': 'foo', 'schemas': None}, {'name': 'bar'}]
+def test_restore_data_source_dump_runs_mongorestore():
+    hook_config = [{'name': 'foo', 'schemas': None}, {'name': 'bar'}]
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename')
     flexmock(module).should_receive('execute_command_with_processes').with_args(
-        ['mongorestore', '--archive', '--drop', '--db', 'foo'],
+        ['mongorestore', '--archive', '--drop'],
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source={'name': 'foo'},
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -186,46 +193,19 @@ def test_restore_database_dump_runs_mongorestore():
     )
 
 
-def test_restore_database_dump_errors_on_empty_databases_config():
-    databases_config = []
-
-    flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
-    flexmock(module).should_receive('execute_command_with_processes').never()
-    flexmock(module).should_receive('execute_command').never()
-
-    with pytest.raises(ValueError):
-        module.restore_database_dump(
-            databases_config,
-            {},
-            'test.yaml',
-            database_name='foo',
-            dry_run=False,
-            extract_process=flexmock(),
-            connection_params={
-                'hostname': None,
-                'port': None,
-                'username': None,
-                'password': None,
-            },
-        )
-
-
-def test_restore_database_dump_runs_mongorestore_with_hostname_and_port():
-    databases_config = [
+def test_restore_data_source_dump_runs_mongorestore_with_hostname_and_port():
+    hook_config = [
         {'name': 'foo', 'hostname': 'database.example.org', 'port': 5433, 'schemas': None}
     ]
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename')
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
             '--archive',
             '--drop',
-            '--db',
-            'foo',
             '--host',
             'database.example.org',
             '--port',
@@ -236,11 +216,11 @@ def test_restore_database_dump_runs_mongorestore_with_hostname_and_port():
         input_file=extract_process.stdout,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -252,8 +232,8 @@ def test_restore_database_dump_runs_mongorestore_with_hostname_and_port():
     )
 
 
-def test_restore_database_dump_runs_mongorestore_with_username_and_password():
-    databases_config = [
+def test_restore_data_source_dump_runs_mongorestore_with_username_and_password():
+    hook_config = [
         {
             'name': 'foo',
             'username': 'mongo',
@@ -265,14 +245,12 @@ def test_restore_database_dump_runs_mongorestore_with_username_and_password():
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename')
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
             '--archive',
             '--drop',
-            '--db',
-            'foo',
             '--username',
             'mongo',
             '--password',
@@ -285,11 +263,11 @@ def test_restore_database_dump_runs_mongorestore_with_username_and_password():
         input_file=extract_process.stdout,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -301,8 +279,8 @@ def test_restore_database_dump_runs_mongorestore_with_username_and_password():
     )
 
 
-def test_restore_database_dump_with_connection_params_uses_connection_params_for_restore():
-    databases_config = [
+def test_restore_data_source_dump_with_connection_params_uses_connection_params_for_restore():
+    hook_config = [
         {
             'name': 'foo',
             'username': 'mongo',
@@ -318,14 +296,12 @@ def test_restore_database_dump_with_connection_params_uses_connection_params_for
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename')
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
             '--archive',
             '--drop',
-            '--db',
-            'foo',
             '--host',
             'clihost',
             '--port',
@@ -342,11 +318,11 @@ def test_restore_database_dump_with_connection_params_uses_connection_params_for
         input_file=extract_process.stdout,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -358,8 +334,8 @@ def test_restore_database_dump_with_connection_params_uses_connection_params_for
     )
 
 
-def test_restore_database_dump_without_connection_params_uses_restore_params_in_config_for_restore():
-    databases_config = [
+def test_restore_data_source_dump_without_connection_params_uses_restore_params_in_config_for_restore():
+    hook_config = [
         {
             'name': 'foo',
             'username': 'mongo',
@@ -375,14 +351,12 @@ def test_restore_database_dump_without_connection_params_uses_restore_params_in_
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename')
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
             '--archive',
             '--drop',
-            '--db',
-            'foo',
             '--host',
             'restorehost',
             '--port',
@@ -399,11 +373,11 @@ def test_restore_database_dump_without_connection_params_uses_restore_params_in_
         input_file=extract_process.stdout,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -415,24 +389,24 @@ def test_restore_database_dump_without_connection_params_uses_restore_params_in_
     )
 
 
-def test_restore_database_dump_runs_mongorestore_with_options():
-    databases_config = [{'name': 'foo', 'restore_options': '--harder', 'schemas': None}]
+def test_restore_data_source_dump_runs_mongorestore_with_options():
+    hook_config = [{'name': 'foo', 'restore_options': '--harder', 'schemas': None}]
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename')
     flexmock(module).should_receive('execute_command_with_processes').with_args(
-        ['mongorestore', '--archive', '--drop', '--db', 'foo', '--harder'],
+        ['mongorestore', '--archive', '--drop', '--harder'],
         processes=[extract_process],
         output_log_level=logging.DEBUG,
         input_file=extract_process.stdout,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -445,18 +419,16 @@ def test_restore_database_dump_runs_mongorestore_with_options():
 
 
 def test_restore_databases_dump_runs_mongorestore_with_schemas():
-    databases_config = [{'name': 'foo', 'schemas': ['bar', 'baz']}]
+    hook_config = [{'name': 'foo', 'schemas': ['bar', 'baz']}]
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename')
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         [
             'mongorestore',
             '--archive',
             '--drop',
-            '--db',
-            'foo',
             '--nsInclude',
             'bar',
             '--nsInclude',
@@ -467,11 +439,11 @@ def test_restore_databases_dump_runs_mongorestore_with_schemas():
         input_file=extract_process.stdout,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -483,12 +455,12 @@ def test_restore_databases_dump_runs_mongorestore_with_schemas():
     )
 
 
-def test_restore_database_dump_runs_psql_for_all_database_dump():
-    databases_config = [{'name': 'all', 'schemas': None}]
+def test_restore_data_source_dump_runs_psql_for_all_database_dump():
+    hook_config = [{'name': 'all', 'schemas': None}]
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename')
     flexmock(module).should_receive('execute_command_with_processes').with_args(
         ['mongorestore', '--archive'],
         processes=[extract_process],
@@ -496,11 +468,11 @@ def test_restore_database_dump_runs_psql_for_all_database_dump():
         input_file=extract_process.stdout,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='all',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -512,18 +484,18 @@ def test_restore_database_dump_runs_psql_for_all_database_dump():
     )
 
 
-def test_restore_database_dump_with_dry_run_skips_restore():
-    databases_config = [{'name': 'foo', 'schemas': None}]
+def test_restore_data_source_dump_with_dry_run_skips_restore():
+    hook_config = [{'name': 'foo', 'schemas': None}]
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename')
     flexmock(module).should_receive('execute_command_with_processes').never()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source={'name': 'foo'},
         dry_run=True,
         extract_process=flexmock(),
         connection_params={
@@ -535,23 +507,23 @@ def test_restore_database_dump_with_dry_run_skips_restore():
     )
 
 
-def test_restore_database_dump_without_extract_process_restores_from_disk():
-    databases_config = [{'name': 'foo', 'format': 'directory', 'schemas': None}]
+def test_restore_data_source_dump_without_extract_process_restores_from_disk():
+    hook_config = [{'name': 'foo', 'format': 'directory', 'schemas': None}]
 
     flexmock(module).should_receive('make_dump_path')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return('/dump/path')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('/dump/path')
     flexmock(module).should_receive('execute_command_with_processes').with_args(
-        ['mongorestore', '--dir', '/dump/path', '--drop', '--db', 'foo'],
+        ['mongorestore', '--dir', '/dump/path', '--drop'],
         processes=[],
         output_log_level=logging.DEBUG,
         input_file=None,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source={'name': 'foo'},
         dry_run=False,
         extract_process=None,
         connection_params={
