@@ -44,7 +44,7 @@ def test_database_names_to_dump_queries_mysql_for_database_names():
     assert names == ('foo', 'bar')
 
 
-def test_dump_databases_dumps_each_database():
+def test_dump_data_sources_dumps_each_database():
     databases = [{'name': 'foo'}, {'name': 'bar'}]
     processes = [flexmock(), flexmock()]
     flexmock(module).should_receive('make_dump_path').and_return('')
@@ -63,10 +63,10 @@ def test_dump_databases_dumps_each_database():
             dry_run_label=object,
         ).and_return(process).once()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False) == processes
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == processes
 
 
-def test_dump_databases_dumps_with_password():
+def test_dump_data_sources_dumps_with_password():
     database = {'name': 'foo', 'username': 'root', 'password': 'trustsome1'}
     process = flexmock()
     flexmock(module).should_receive('make_dump_path').and_return('')
@@ -84,10 +84,10 @@ def test_dump_databases_dumps_with_password():
         dry_run_label=object,
     ).and_return(process).once()
 
-    assert module.dump_databases([database], {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources([database], {}, 'test.yaml', dry_run=False) == [process]
 
 
-def test_dump_databases_dumps_all_databases_at_once():
+def test_dump_data_sources_dumps_all_databases_at_once():
     databases = [{'name': 'all'}]
     process = flexmock()
     flexmock(module).should_receive('make_dump_path').and_return('')
@@ -102,10 +102,10 @@ def test_dump_databases_dumps_all_databases_at_once():
         dry_run_label=object,
     ).and_return(process).once()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False) == [process]
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == [process]
 
 
-def test_dump_databases_dumps_all_databases_separately_when_format_configured():
+def test_dump_data_sources_dumps_all_databases_separately_when_format_configured():
     databases = [{'name': 'all', 'format': 'sql'}]
     processes = [flexmock(), flexmock()]
     flexmock(module).should_receive('make_dump_path').and_return('')
@@ -122,7 +122,7 @@ def test_dump_databases_dumps_all_databases_separately_when_format_configured():
             dry_run_label=object,
         ).and_return(process).once()
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False) == processes
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False) == processes
 
 
 def test_database_names_to_dump_runs_mysql_with_list_options():
@@ -144,7 +144,7 @@ def test_database_names_to_dump_runs_mysql_with_list_options():
 
 def test_execute_dump_command_runs_mysqldump():
     process = flexmock()
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return('dump')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('dump')
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
@@ -177,7 +177,7 @@ def test_execute_dump_command_runs_mysqldump():
 
 def test_execute_dump_command_runs_mysqldump_without_add_drop_database():
     process = flexmock()
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return('dump')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('dump')
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
@@ -209,7 +209,7 @@ def test_execute_dump_command_runs_mysqldump_without_add_drop_database():
 
 def test_execute_dump_command_runs_mysqldump_with_hostname_and_port():
     process = flexmock()
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return('dump')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('dump')
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
@@ -248,7 +248,7 @@ def test_execute_dump_command_runs_mysqldump_with_hostname_and_port():
 
 def test_execute_dump_command_runs_mysqldump_with_username_and_password():
     process = flexmock()
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return('dump')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('dump')
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
@@ -283,7 +283,7 @@ def test_execute_dump_command_runs_mysqldump_with_username_and_password():
 
 def test_execute_dump_command_runs_mysqldump_with_options():
     process = flexmock()
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return('dump')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('dump')
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
@@ -316,7 +316,7 @@ def test_execute_dump_command_runs_mysqldump_with_options():
 
 
 def test_execute_dump_command_with_duplicate_dump_skips_mysqldump():
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return('dump')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('dump')
     flexmock(module.os.path).should_receive('exists').and_return(True)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump').never()
     flexmock(module).should_receive('execute_command').never()
@@ -336,7 +336,7 @@ def test_execute_dump_command_with_duplicate_dump_skips_mysqldump():
 
 
 def test_execute_dump_command_with_dry_run_skips_mysqldump():
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return('dump')
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return('dump')
     flexmock(module.os.path).should_receive('exists').and_return(False)
     flexmock(module.dump).should_receive('create_named_pipe_for_dump')
 
@@ -356,31 +356,31 @@ def test_execute_dump_command_with_dry_run_skips_mysqldump():
     )
 
 
-def test_dump_databases_errors_for_missing_all_databases():
+def test_dump_data_sources_errors_for_missing_all_databases():
     databases = [{'name': 'all'}]
     flexmock(module).should_receive('make_dump_path').and_return('')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return(
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
         'databases/localhost/all'
     )
     flexmock(module).should_receive('database_names_to_dump').and_return(())
 
     with pytest.raises(ValueError):
-        assert module.dump_databases(databases, {}, 'test.yaml', dry_run=False)
+        assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=False)
 
 
-def test_dump_databases_does_not_error_for_missing_all_databases_with_dry_run():
+def test_dump_data_sources_does_not_error_for_missing_all_databases_with_dry_run():
     databases = [{'name': 'all'}]
     flexmock(module).should_receive('make_dump_path').and_return('')
-    flexmock(module.dump).should_receive('make_database_dump_filename').and_return(
+    flexmock(module.dump).should_receive('make_data_source_dump_filename').and_return(
         'databases/localhost/all'
     )
     flexmock(module).should_receive('database_names_to_dump').and_return(())
 
-    assert module.dump_databases(databases, {}, 'test.yaml', dry_run=True) == []
+    assert module.dump_data_sources(databases, {}, 'test.yaml', dry_run=True) == []
 
 
-def test_restore_database_dump_runs_mysql_to_restore():
-    databases_config = [{'name': 'foo'}, {'name': 'bar'}]
+def test_restore_data_source_dump_runs_mysql_to_restore():
+    hook_config = [{'name': 'foo'}, {'name': 'bar'}]
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('execute_command_with_processes').with_args(
@@ -391,11 +391,11 @@ def test_restore_database_dump_runs_mysql_to_restore():
         extra_environment=None,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source={'name': 'foo'},
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -407,31 +407,8 @@ def test_restore_database_dump_runs_mysql_to_restore():
     )
 
 
-def test_restore_database_dump_errors_when_database_missing_from_configuration():
-    databases_config = [{'name': 'foo'}, {'name': 'bar'}]
-    extract_process = flexmock(stdout=flexmock())
-
-    flexmock(module).should_receive('execute_command_with_processes').never()
-
-    with pytest.raises(ValueError):
-        module.restore_database_dump(
-            databases_config,
-            {},
-            'test.yaml',
-            database_name='other',
-            dry_run=False,
-            extract_process=extract_process,
-            connection_params={
-                'hostname': None,
-                'port': None,
-                'username': None,
-                'password': None,
-            },
-        )
-
-
-def test_restore_database_dump_runs_mysql_with_options():
-    databases_config = [{'name': 'foo', 'restore_options': '--harder'}]
+def test_restore_data_source_dump_runs_mysql_with_options():
+    hook_config = [{'name': 'foo', 'restore_options': '--harder'}]
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('execute_command_with_processes').with_args(
@@ -442,11 +419,11 @@ def test_restore_database_dump_runs_mysql_with_options():
         extra_environment=None,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -458,8 +435,8 @@ def test_restore_database_dump_runs_mysql_with_options():
     )
 
 
-def test_restore_database_dump_runs_mysql_with_hostname_and_port():
-    databases_config = [{'name': 'foo', 'hostname': 'database.example.org', 'port': 5433}]
+def test_restore_data_source_dump_runs_mysql_with_hostname_and_port():
+    hook_config = [{'name': 'foo', 'hostname': 'database.example.org', 'port': 5433}]
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('execute_command_with_processes').with_args(
@@ -479,11 +456,11 @@ def test_restore_database_dump_runs_mysql_with_hostname_and_port():
         extra_environment=None,
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -495,8 +472,8 @@ def test_restore_database_dump_runs_mysql_with_hostname_and_port():
     )
 
 
-def test_restore_database_dump_runs_mysql_with_username_and_password():
-    databases_config = [{'name': 'foo', 'username': 'root', 'password': 'trustsome1'}]
+def test_restore_data_source_dump_runs_mysql_with_username_and_password():
+    hook_config = [{'name': 'foo', 'username': 'root', 'password': 'trustsome1'}]
     extract_process = flexmock(stdout=flexmock())
 
     flexmock(module).should_receive('execute_command_with_processes').with_args(
@@ -507,11 +484,11 @@ def test_restore_database_dump_runs_mysql_with_username_and_password():
         extra_environment={'MYSQL_PWD': 'trustsome1'},
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -523,8 +500,8 @@ def test_restore_database_dump_runs_mysql_with_username_and_password():
     )
 
 
-def test_restore_database_dump_with_connection_params_uses_connection_params_for_restore():
-    databases_config = [
+def test_restore_data_source_dump_with_connection_params_uses_connection_params_for_restore():
+    hook_config = [
         {
             'name': 'foo',
             'username': 'root',
@@ -556,11 +533,11 @@ def test_restore_database_dump_with_connection_params_uses_connection_params_for
         extra_environment={'MYSQL_PWD': 'clipassword'},
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source={'name': 'foo'},
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -572,8 +549,8 @@ def test_restore_database_dump_with_connection_params_uses_connection_params_for
     )
 
 
-def test_restore_database_dump_without_connection_params_uses_restore_params_in_config_for_restore():
-    databases_config = [
+def test_restore_data_source_dump_without_connection_params_uses_restore_params_in_config_for_restore():
+    hook_config = [
         {
             'name': 'foo',
             'username': 'root',
@@ -607,11 +584,11 @@ def test_restore_database_dump_without_connection_params_uses_restore_params_in_
         extra_environment={'MYSQL_PWD': 'restorepass'},
     ).once()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source=hook_config[0],
         dry_run=False,
         extract_process=extract_process,
         connection_params={
@@ -623,16 +600,16 @@ def test_restore_database_dump_without_connection_params_uses_restore_params_in_
     )
 
 
-def test_restore_database_dump_with_dry_run_skips_restore():
-    databases_config = [{'name': 'foo'}]
+def test_restore_data_source_dump_with_dry_run_skips_restore():
+    hook_config = [{'name': 'foo'}]
 
     flexmock(module).should_receive('execute_command_with_processes').never()
 
-    module.restore_database_dump(
-        databases_config,
+    module.restore_data_source_dump(
+        hook_config,
         {},
         'test.yaml',
-        database_name='foo',
+        data_source={'name': 'foo'},
         dry_run=True,
         extract_process=flexmock(),
         connection_params={
